@@ -174,7 +174,7 @@ class VariableOsRootTypeExt(ReadonlyVariable):
             if "/dev/ram" in root_dev:
                 record = readFile('/proc/cmdline').strip()
                 if "iso-scan/filename" in record:
-                    if path.join(Dracut.IsoScanPath, "grub.cfg"):
+                    if path.exists(path.join(Dracut.IsoScanPath, "grub.cfg")):
                         return RootType.Value.IsoScanGrub
                     else:
                         return RootType.Value.IsoScanFlash
